package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````[!\```````!``````````,BA````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````':@`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````X)<`````
M``#@EP`````````0`````````0````8```"8FP```````)BK````````F*L`
M``````"X!````````.`$`````````!`````````"````!@```+";````````
ML*L```````"PJP```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0```!0CP```````%"/````````4(\```````#L````````
M`.P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````F)L```````"8
MJP```````)BK````````:`0```````!H!`````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`*7\(\AV-,3D"9)L0#:2&N[*1Q&(!````!`````!````1TY5```````$````
M#P`````````1````1P````0````(````()`0`05`!,0H`@$$@(8$A(*)``()
M(`0(B(`00;H``H@`````1P```$H```!-````3@```%8```!7````60```%L`
M``!<````70```%\```!A````8@```&0``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@
MF4_#FVL)0]9FK\QF&7X*AT)%U>R)!W#3<U"?V#-BV^T^S])L%8PES`PZEPO_
M8?)A?ZF<F^"G`@IK&IY0H^#[20``````````````````````````````````
M`````````P`,`$`>``````````````````#G`@``$0``````````````````
M``````#5````$@````````````````````````#%`0``$@``````````````
M``````````##`@``$@````````````````````````"'````$@``````````
M``````````````!.`0``$@````````````````````````"6`@``$@``````
M``````````````````#,`0``$@````````````````````````!E`0``$@``
M``````````````````````"5`0``$@````````````````````````#K````
M$@````````````````````````"R`@``$@````````````````````````#-
M`@``$0````````````````````````"=`@``$@``````````````````````
M``"(`0``$@`````````````````````````<`0``$@``````````````````
M```````,`0``$@````````````````````````#^````$@``````````````
M``````````#Q`0``$@````````````````````````#3`0``$@``````````
M``````````````"^`0``$@````````````````````````#5`@``$@``````
M```````````````````!````(``````````````````````````'`@``$@``
M``````````````````````!L`0``$@`````````````````````````=````
M(`````````````````````````!#`@``$@````````````````````````"F
M`0``$@`````````````````````````W````$@``````````````````````
M``"D`@``$@````````````````````````#+`@``$0``````````````````
M``````!4````%@```````````````````````````@``$@``````````````
M```````````^`0``$@````````````````````````"K`@``$@``````````
M```````````````F`@``$@````````````````````````!G````$@``````
M``````````````````"``@``$@````````````````````````#$````$@``
M``````````````````````!X````$@````````````````````````"-`0``
M$@````````````````````````"H````$@````````````````````````#:
M````$@````````````````````````!Y`@``$@``````````````````````
M``#K`0``$@`````````````````````````P`0``$@``````````````````
M``````"?`0``$@````````````````````````!C`@``$@``````````````
M``````````!<`@``$0````````````````````````#?````$@``````````
M``````````````"V`0``$@````````````````````````!"`@``$@``````
M``````````````````!J`@``(@````````````````````````"3````$@``
M```````````````````````0`@``$@````````````````````````#9`0``
M$@````````````````````````"'`@``$@````````````````````````!9
M`0``$@`````````````````````````T`@``$@``````````````````````
M``"O`P``$@````````````````````````"W````$0``````````````````
M```````8`@``$@`````````````````````````E`0``$@``````````````
M``````````!%````$@````````````````````````!*`@``$@``````````
M``````````````".`@``$@````````````````````````#>`0``$@``````
M``````````````````!W`0``$@````````````````````````"O`0``$@``
M``````````````````````"X`P``$@`,`-8V````````M@````````!*!```
M$@`,`-@O````````.`4```````!7`@``$@`,`$`>````````K`$````````O
M`P``$@`,`,@F````````#`````````!-`P``$@`,`!`U````````Q@$`````
M``!P!```$@`,`-0F````````O`$````````P!```$``6`%"P````````````
M``````!``P``$@`,`)`H````````*`````````!C`P``$@`,`"@M````````
M6@````````#0`P``$0`-`-A-````````!``````````-!```$@`,`!I+````
M````Z@`````````H!```$@`,`-PE````````,@````````!%!```$``6`'BP
M``````````````````!>!```$@`,``8O````````T@````````"'!```$@`,
M`((M````````4`````````#?`P``$``5``"P``````````````````"'`P``
M$@`,`+@H````````\@````````#[`P``$`#Q_P"X``````````````````!7
M!```$``5`%"P``````````````````!]!```$0`5`$BP````````"```````
M```8!```$``5`%"P``````````````````#E`P``$@`,`.P?````````(@``
M``````#L`P``$``5``"P```````````````````\!```$@`,`,!*````````
M6@````````#A`P``(``5``"P``````````````````#$`P``$``6`'BP````
M``````````````"=`P``$@`,`.@N````````'@````````!Q`P``$@`,``XF
M````````N@````````"3`P``$@`,``1,````````N`$```````"/!```$@`,
M`*HI````````?@,`````````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C
M:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N
M=&5X=`!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F
M;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?
M;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S
M90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!?7W-T86-K7V-H:U]F
M86EL`&5X:70`;'-E96LV-`!R96%D9&ER-C0`<W1R9'5P`&-L;W-E9&ER`&]P
M96XV-`!S=')R8VAR`'5N;&EN:P!S=')T;VL`<W1R;&5N`')M9&ER`')E860`
M7U]M96UC<'E?8VAK`&UK9&ER`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!R96%D
M;&EN:P!R96%L;&]C`%]?<W!R:6YT9E]C:&L`7U]M96UM;W9E7V-H:P!?7V9P
M<FEN=&9?8VAK`&QS=&%T-C0`7U]L:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE
M;6-H<@!?7V-X85]F:6YA;&EZ90!S=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N
M9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T
M:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A
M8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`;&0M;&EN
M=7@M<FES8W8V-"UL<#8T9"YS;RXQ`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A
M<V5N86UE`%A37TEN=&5R;F%L<U]005)?0D]/5`!P87)?96YV7V-L96%N`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!P87)?9&ER;F%M90!S:&%?9FEN86P`9V5T
M7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]"4U-?14Y$
M7U\`7TE/7W-T9&EN7W5S960`7U]D871A7W-T87)T`%]?1$%405]"14=)3E]?
M`%]?9VQO8F%L7W!O:6YT97(D`'-H85]U<&1A=&4`7U]31$%405]"14=)3E]?
M`'AS7VEN:70`7U]B<W-?<W1A<G0`<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D
M:7(`7V5D871A`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!M>5]P
M87)?<&P`<&%R7V1I90!P87)?:6YI=%]E;G8`1TQ)0D-?,BXS-`!'3$E"0U\R
M+C,S`$=,24)#7S(N,C<````````"``$``P`#``$``0`#``,``P`#``$``P`#
M``,``P`!``$``0`#``,``P`#``$``P`!``$`!``#``$``P`#``$``P`!``,`
M`P`!``,``0`!``,``0`#``,``P`!``,``P`#``$``P`$``,``0`#``,``P`!
M``,``P`!``,``0`!``4``P`#``,``P`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``,`"0,`
M`!````!`````M)&6!@``!0"<!```$````+.1E@8```0`IP0``!````"'D98&
M```#`+($`````````0`!`!,#```0`````````(>1E@8```(`L@0```````"8
MJP````````,`````````#B````````"@JP````````,`````````HB``````
M``"HJP````````,`````````:"````````#XKP````````,`````````0!X`
M````````L`````````,``````````+`````````8L`````````,`````````
M.$\````````@L`````````,`````````H%$````````HL`````````,`````
M````J%$````````PL`````````,`````````L%$````````XL`````````,`
M````````N%$```````!(L`````````,`````````P%$```````"@KP``````
M``(````"``````````````"HKP````````(````,``````````````"PKP``
M``````(````.``````````````"XKP````````(````8``````````````#`
MKP````````(````;``````````````#(KP````````L````A````````````
M``#0KP````````(````C``````````````#8KP````````(````F````````
M``````#@KP````````(````R``````````````#HKP````````(````V````
M``````````#PKP````````(````^``````````````#0K0````````4````#
M``````````````#8K0````````4````$``````````````#@K0````````4`
M```%``````````````#HK0````````4````&``````````````#PK0``````
M``4````'``````````````#XK0````````4````(````````````````K@``
M``````4````)```````````````(K@````````4````*```````````````0
MK@````````4````+```````````````8K@````````4````-````````````
M```@K@````````4````/```````````````HK@````````4````0````````
M```````PK@````````4````1```````````````XK@````````4````2````
M``````````!`K@````````4````3``````````````!(K@````````4````4
M``````````````!0K@````````4````5``````````````!8K@````````4`
M```6``````````````!@K@````````4````7``````````````!HK@``````
M``4````9``````````````!PK@````````4````:``````````````!XK@``
M``````4````<``````````````"`K@````````4````=``````````````"(
MK@````````4````>``````````````"0K@````````4````?````````````
M``"8K@````````4````B``````````````"@K@````````4````D````````
M``````"HK@````````4````E``````````````"PK@````````4````G````
M``````````"XK@````````4````H``````````````#`K@````````4````I
M``````````````#(K@````````4````J``````````````#0K@````````4`
M```K``````````````#8K@````````4````L``````````````#@K@``````
M``4````M``````````````#HK@````````4````N``````````````#PK@``
M``````4````O``````````````#XK@````````4````P````````````````
MKP````````4````Q```````````````(KP````````4````S````````````
M```0KP````````4````T```````````````8KP````````4````U````````
M```````@KP````````4````W```````````````HKP````````4````X````
M```````````PKP````````4````Y```````````````XKP````````4````Z
M``````````````!`KP````````4````[``````````````!(KP````````4`
M```\``````````````!0KP````````4````]``````````````!8KP``````
M``4````_``````````````!@KP````````4```!```````````````!HKP``
M``````4```!!``````````````!PKP````````4```!"``````````````!X
MKP````````4```!#``````````````"`KP````````4```!$````````````
M``"(KP````````4```!%``````````````"0KP````````4```!&````````
M``````"7DP``,P/#00.^`S,3`T/]DX(#,Q-3$P"#LH(`9P`.`!>>```#/@XR
M9P,.`!,````7G@```SZ.,6<##@`3````%YX```,^#C%G`PX`$P```!>>```#
M/HXP9P,.`!,````7G@```SX.,&<##@`3````%YX```,^CB]G`PX`$P```!>>
M```#/@XO9P,.`!,````7G@```SZ.+F<##@`3````%YX```,^#BYG`PX`$P``
M`!>>```#/HXM9P,.`!,````7G@```SX.+6<##@`3````%YX```,^CBQG`PX`
M$P```!>>```#/@XL9P,.`!,````7G@```SZ.*V<##@`3````%YX```,^#BMG
M`PX`$P```!>>```#/HXJ9P,.`!,````7G@```SX.*F<##@`3````%YX```,^
MCBEG`PX`$P```!>>```#/@XI9P,.`!,````7G@```SZ.*&<##@`3````%YX`
M``,^#BAG`PX`$P```!>>```#/HXG9P,.`!,````7G@```SX.)V<##@`3````
M%YX```,^CB9G`PX`$P```!>>```#/@XF9P,.`!,````7G@```SZ.)6<##@`3
M````%YX```,^#B5G`PX`$P```!>>```#/HXD9P,.`!,````7G@```SX.)&<#
M#@`3````%YX```,^CB-G`PX`$P```!>>```#/@XC9P,.`!,````7G@```SZ.
M(F<##@`3````%YX```,^#B)G`PX`$P```!>>```#/HXA9P,.`!,````7G@``
M`SX.(6<##@`3````%YX```,^CB!G`PX`$P```!>>```#/@X@9P,.`!,````7
MG@```SZ.'V<##@`3````%YX```,^#A]G`PX`$P```!>>```#/HX>9P,.`!,`
M```7G@```SX.'F<##@`3````%YX```,^CAUG`PX`$P```!>>```#/@X=9P,.
M`!,````7G@```SZ.'&<##@`3````%YX```,^#AQG`PX`$P```!>>```#/HX;
M9P,.`!,````7G@```SX.&V<##@`3````%YX```,^CAIG`PX`$P```!>>```#
M/@X:9P,.`!,````7G@```SZ.&6<##@`3````%YX```,^#AEG`PX`$P```!>>
M```#/HX89P,.`!,````7G@```SX.&&<##@`3````%YX```,^CA=G`PX`$P``
M`!>>```#/@X79P,.`!,````7G@```SZ.%F<##@`3````%YX```,^#A9G`PX`
M$P```!UQANRBZ,K@@!"FY$[\4OBJAQ>9```#.>D4(SBT^B,TQ/J3!03[$P:$
M^A,%Q/LC+O3Z@S<)`",T]/R!1^_P7_87E@```S:&$K*%%Y4```,UY13O(+!R
MEY<``(.WIQ6#QP<`8X4'#I>7``"#MR<2EY0``).$I!J2EYAC@RG$^X-'ITL;
MA4D`#@63YS<`(PWW2N_P'^R#-03[@R?$^XCDF&&-*:J&&.$7-P``$P>G*ACE
M%Y<```,WAQ48Z1<W```3!^<I&.T%1V-<]PP;B#<`0H:A!1%'B&&3%S<`MI<%
M)XCCH07C&0?_FP<&`(X'B&RVEP%'3H:7!0``DX6%9".P!P#O\!^[-<F(;!,*
M1/SO\%_:JHG2A1<U```3!47W[P"`%"7!B&SO\-^T[_"?RP,WA/R#-PD`N8\!
M1Z7KYF!&9*9D!FE">DZ%XGDE88*`[_!?QI>4``"3A(0,B.PAQ>_P7\^7EP``
M@[>'`H5F,X='`!AC-I<C!P>:`;>(;._P?[MAMXAH`<7O$"!Q:;_2A1<U```3
M!47H[P``#8CH0=7EMY%'J;<%1>_PW[?O\)_C[P`@`JJ'%Y4```,U90""93``
M$W$!_X%&`4<*B._PG]X"D)>1``"3@2%_@H```!>5```3!64#EY<``).'YP)C
MB*<`EY<``(.WI_B1PX*'@H`7E0``$P5%`9>5``"3A<4`B8V3US5`_9&^E86%
MF<67EP``@[=G]I'#@H>"@$$1(N`7E```$P1$_H-'!``&Y(7CEY<``(.WQ_:1
MQQ>5```#-:7W@I?O\+_XA4<C`/0`HF`"9$$!@H!IOUUQHN"&Y";\@`A1R5[D
MEY<``(.WY^^#NP<`8X0+"$[T4O!6[(-'!0`JBJZ*JHD3!]`#O<MCAN<`@\<9
M`(4)_?N[B4E!@[0+`+7`2OA:Z%Z)$PO0`TZ&TH4FA>_P/YVSAS0!">6#QP<`
M8X)G`X,TB0`A">WP0GFB>0)ZXFI":Z)KIF`&9":%XG1A88*`,PEY01-9.4"%
M"2.@*@'.E.&_@43%MZ)K@43IOX%):;^B>0)ZXFJB:_&W<7$B\2;M2ND`&0;U
M%YD```,YJ>.3!83U@S<)`",\]/R!1ZJ$[_`_O!7A@R>$]KUF$6?UCV.%YP`I
M9V.:YP")12:%[_!?FQ,U%0`1H`%%`S>$_8,W"0"YCP%'F>>J<`ITZF1*:4UA
M@H#O\/_%57&BX5+QAN6`"1>:```#.@K=@S<*`",\]/J!1QG%)OV#1P4`JH29
M[^IT`S>$^X,W"@"YCP%'8YH'#*Y@#F0*>FEA@H!*^4[U[_`_ORJ)2<U*A>_P
MGY%9P8-&-0&3"34!FX8F_8'F@\89`/W2`T<U`1L')_TUSR:%5NWO\!^-JHI.
MA>_PGXR[BJH`B2I6A>_PWXS.AR:'ES8``).&1KA6AHE%JHGO\'^UDP6$\TZ%
M[_#?F/U78PGU`(,GA/2]9A%G]8]C@.<$3H7O\#^33H7O\-^B2H7J:N_P7XD]
M_4J%[_#?EB:%[_!_D.IT2GFJ>36_`\<9`!L')_T]_P/'*0`IVYV_3H7O\-_O
MT;<F_4KY3O56[>_PG[19<:+PINS*Z,[D5OR&]-+@7O1B\(`8@\<%`)>9``"#
MN:G**HF3AS?\D[<7`+.$]0`FA8.W"0`C//3X@4?O\(__JHJ3!43Y2H7O\!_8
M><TJBN_P3_YC>E4+@RM$^1><```#/(S'C@L#1PD`RH>3!M`#8P`'%&,&UP`#
MQQ<`A0=]^[N')T$#.@P`$X4J`#Z57IKO\$_[(S"J`#'%`S<,`(-'"0`3!1D`
M7I<48Q,&T`,C@/8`@>N-J(-'!0`%!:,`]P"]PS:'A0;CF,?^DP;0`Y,'%P`C
M`-<``\<$`(4'A02CC^?^=?L#-X3Y@[<)`+F/`4?IYZ9P!G3F9$9IIFD&:N)Z
MHGL"?&5A@H"#QP0`!0J%!*,/^O[AVX/'!``%"H4$HP_Z_OWSP;<VATVW6OAF
M[&KH%YP```,\3+H#/0P`@S<-`+7+ZH<!2IAGTH:A!P4J9?^-)A.;-@"7EP``
MDX=GPIA##>\%1UJ%F,/O\,_MJHPYR9,;.@#:AEZ&ZH7O\+^`(S"<`9L'&@".
M![Z<([`,`$)[XFQ";2,J1/GYM=J%:H7O\'^.(S"L`*J,$<V3&SH`T;^!1\F]
M04L!2GF_6OAF[&KH[_!?F$)[XFQ";2F_77&BX";\2OA.]%+P5NR`"(;D_7?]
M<I.'A_N%9)>9``"#N<FM%I&JBBZ*$X;T_[.%AP`7-0``$P7ED(.W"0`C//3Z
M@4?O\$_O&PD%`&-=(`$3!P3\LP270)L'^?^^E`/'A/\=[XWOEY<``(.WIZM2
MAM:%DI>(8^_P+^<#-X3[@[<)`+F/`4>IYX5B%I&F8`9DXG1">:)Y`GKB:F%A
M@H`^B?UWDX>'^[.$AP!*AI,%\`(FA>_P;_M%V9>7``"#MX>FRH8FAI*7B&/6
MA>_P[_-UM^_PGXH!$2;DEY0``(.TA*0BZ`;L`!"SAT0`B&.7=@``DX;&F1>6
M```#-D:CES4``).%187O\%^"DI1"9(A@XF"B9!<W```3!^>\@4>ZAA<6```3
M!J;TES4``).%I80%86_PC^I!$9>7``"#MZ>>(N0`"")DDI>(8Y=V``"3A@:4
M%Y8```,VAIV7)0``DX6%?T$!;_!O_!UQANRBZ*;D@!#*X$[\4OA6]/ER%YH`
M``,ZZI<6D8,W"@`C//3Z@4?O\*_@^7>3AX?ZLX2'``5F*H>7)P``DX>'?I<F
M``"3AH9^!0:)12:%[_`O]OUUDX<%^S.)AP`FA05FRH7O\._6FP0%`(%)8\$$
M`IN*%`!6A>_PK\FJB0G))H;6ALJ%SI3O\*_W(X`$``,WA/N#-PH`N8\!1XGO
MB6(6D>9@3H5&9*9D!FGB>4)ZHGHE88*`[_#/]4$1(N0`"")D00$UOQ%QHOFF
M]<KQSNUB^0`"AOW2Z=;EVN%>_6;U:O%N[?UW_7*3AT?P%YP```,\;(H6D2J)
MKHD7)0``$P6%=+.%AP"#-PP`(S3T^(%'[_!_F*J$DP7P`DJ%[_!OVC'!%R4`
M`!,%!7/*A>_P/[I*A0,WA/B#-PP`N8\!1V.0!Q2%8A:1[G!.=*YT#GGN:4YJ
MKFH.:^I[2GRJ?`I]ZFT188*`3H7O\,_8ER4``).%A6_O\`^T*HU-U?UY?7J3
MAXGXLXF'`),'BO"%:C.*AP"3!P3YLXQ708-'#0"7*P``DXOK;!<K```3"^ML
MR<N1Q.J%)H7O\._(-<5JA>_P;[23!_7_ZI>JC9,&\`)C:/T`,:@C@`<`_1=C
M!OT``\<'`.,)U_YJA>_PS[&JC4J%[_!/L6Z5!07C=E7SB45*B-Z':H?:A@5F
M3H7O\*_:TH5.A>_P+[X!Z8.GC/B]9B%G]8]CC^<"ER4``).%Y6,!1>_P3Z@J
MC>,'!>Z#1PT`K?N1Q(/'!`";AR?]F<>%31<M```3#>U>8;^#QQ0`Z=?]MX5%
M3H7O\`^N7?W.A1<E```3!85>[_#?I4Z%[_"OQUV][_!/V0$1(N@FY`;L`!"3
M!?`"JH3O\`_)&<&3!!4`0F3B8":%HF0%86_PS\0Y<2+X3NP&_";T2O"``)>)
M``"#N:EM_7*#MPD`(S3T_(%'%I%9R8-'!0`JB=G'[_"OHA,&%0"%9ZJ$8^C'
M"GUWDP>'_#.'AP#*A3J%[_#/LI.']/^JEY,&\`)C:/4`$:@C@`<`_1=CAJ<`
M`\<'`.,)U_Y]=9,'A?RSA(<`DP7P`B:%[_!OOQ7)8^ZD!'UUDP>%_#.%AP#O
M\"^[`S>$_(.W"0"YCP%'H>>%8A:1XG!"=*)T`GGB:2%A@H`#-X3\@[<)`+F/
M`4>%YX5B%I'B<$)THG0">>)I%R4``!,%I4LA86_PC[8C``4`5;<!17VW[_"O
MQSEQ(O@F]$KP3NQ2Z(``!OP7B0```SEI7H,W"0`C-/3\@4>3!$3\ERD``).)
MB4L7B@```SJ*7::%3H7O\`_L'<$#)T3\@S<*``X'NI>89YCC?=.8:Z$'F.-M
M_Z:%3H7O\,_I>?V7*0``DXFI2!>*```#.JI9IH5.A>_P+^@=P0,G1/R#-PH`
M#@>ZEYAGF.-]TYAKH0>8XVW_IH5.A>_P[^5Y_9<I``"3B4E%%XH```,ZRE6F
MA4Z%[_!/Y!W!`R=$_(,W"@`.![J7F&>8XWW3F&NA!YCC;?^FA4Z%[_`/XGG]
MERD``).):4(7B@```SKJ4::%3H7O\&_@'<$#)T3\@S<*``X'NI>89YCC?=.8
M:Z$'F.-M_Z:%3H7O\"_>>?V7*0``DXD)/Q>*```#.@I.IH5.A>_PC]P=P0,G
M1/R#-PH`#@>ZEYAGF.-]TYAKH0>8XVW_IH5.A>_P3]IY_9<I``"3B2D\%XH`
M``,Z*DJFA4Z%[_"OV!W!`R=$_(,W"@`.![J7F&>8XWW3F&NA!YCC;?^FA4Z%
M[_!OUGG]ERD``).)R3`7B@```SI*1J:%3H7O\,_4'<$#)T3\@S<*``X'NI>8
M9YCC?=.8:Z$'F.-M_Z:%3H7O\(_2>?V7*0``DXEI-1>*```#.FI"IH5.A>_P
M[]`=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8XVW_IH5.A>_PK\YY_9<I``"3
MB8DR%XH```,ZBCZFA4Z%[_`/S1W!`R=$_(,W"@`.![J7F&>8XWW3F&NA!YCC
M;?^FA4Z%[_#/RGG]ERD``).)J2\7B@```SJJ.J:%3H7O\"_)'<$#)T3\@S<*
M``X'NI>89YCC?=.8:Z$'F.-M_Z:%3H7O\._&>?V7*0``DXE)(A>*```#.LHV
MIH5.A>_P3\4=P0,G1/R#-PH`#@>ZEYAGF.-]TYAKH0>8XVW_IH5.A>_P#\-Y
M_::%%R4``!,%Q2CO\`_"JH49Q1<E```3!<4E[_"/Y*:%%R4``!,%92CO\"_`
MJH49Q1<E```3!>4H[_"OXJ:%%R4``!,%!2GO\$^^JH4=S1<E```3!848[_#/
MX`,WA/R#-PD`N8\!1['C0G3B<*)T`GGB:4)JER4``).%)2@7)0``$P4E'"%A
M;_#/W::%%R4``!,%)27O\&^YJH5AT1<E```3!24<[_#OVTV_[_#/CWEQ(O`F
M[``8!O27A```@[3D)I,%1/T7)0``$P6E&9Q@(SST_(%'[_!OM07%@T<%``%%
MB<>3AP?],S7P``,WA/V<8+F/`4>!ZZ)P`G3B9$5A@H`!1>6W[_`OBAUQ(N@&
M[``0*HX7A0```S5%)0AA$P.$``SD$.@4[!ST&/`C.`0#(SP4`Y>'``"#MT<?
MFH9RAHE%F&,C-.3^`4<C,&3^[^"_W1,%\`_OX#_967&B\-+@5OQJZ(;TINS*
MZ,[D6OA>]&+P9NR`&,%R%XT```,]#1N#-PT`(SST^(%'%I$)1H%%JHKOX'_I
M$PKU_Q-7^D-!D[,'Z@#"%\&3F8\S"OI`8T$*"D%Y06R3!PGY?5LSB8<`(0R=
M3)>)``"3B<D<P7L!1M*%5H7OX%_E8P1E"6*&RH56A>_@?_$!)6,&90=C_ZP$
M816S!*D`8_8D`8&H_11CYB0%(4;.A2:%[^`?WV7YP7>3AP?YHI<SA?1`4I4#
M-X3Y@S<-`+F/`4>QX\%B%I&F<`9TYF1&::9I!FKB>D)[HGL"?.)L0FUE88*`
M7IKC$7KY?57IMQ<E```3!<4+[_#_ZA<E```3!04*[_`_ZN_@W_-!$2+@!N0`
M"._@'\$!)>_@O^L1P0AAHF`"9$$!@H`Y<2+X2O!.[(``!OR7B0``@[GI""J)
MDP5$_!<E```3!84'@[<)`",T]/R!1^_P+Y<9Q2;T@T<%`*J$C>>B=`,WA/R#
MMPD`N8\!1\J%%R4``!,%902MZT)TXG`">>)I(6%O\&^W2H52Z._@/[HJBB:%
M[^"_N2J:"0I2A>_@'[HFB)<G``"3AZ?N2H>7)@``DX8&[U*&B46JA._@/^(#
M-X3\@[<)`+F/`4>=XT)T0FKB<`)YXFFFA:)T%R4``!,%I?TA86_P3[$F]%+H
M[^`?Y>_@W^0E<2+K2N,`$\[^TOH&[R;GEX<``).'!P*#N`<!`[B'`9!SE'>8
M>YQ_%XH```,Z"OH#,PH`(SQD^`%#%R,``!,#X_D3"<3G(SST[)<G``"3AV?Y
MJHDC,&3H(SSTZ!<C```3`T/AER<``).'1_C*A1<E```3!:7@(S1DZ",X!.@C
M.!3K(SP$ZR,PQ.PC--3L(SCD[",P].HC-`3J[_`O@Q'%@T<%`*J$8Y`')-;V
MVO+>[N+JYN;OX%^G`27OX/_18PH%&(,[!0!CA@L87H7OX-^FDQ05`(4$)H7O
MX!^G`\<+`"J,IHRJB@W/%RL``!,+"_':AB:&B45BA>_@'\^%"^:&8_.<`*:&
MLX>60(D'8_/7`+:'`\<+`/D4E8R^E`D,:?L3"P3K%R4``!,%Q>,IH`,UBP`A
M"PW!RH7OX%_YJH1EV8-'!0#MU^_PSX-UT2:%[^"_O:J$%>$3"P3H@S0+`(G,
M@\<$`&.%!PXFA>_PCX%AZ8,TBP`A"^WT)H7OX/^;*HM6A>_@?YL["ZL`&PM+
M0%J%[^"?FY<G``"3A\?0UH@7*```$P@HYB:'ER8``).&!N9:AHE%JHOOX#_#
MDP4`'%Z%[^"?M/U78QCU`._@_YD<045'8YKG#I,%!.Y>A>_@W[BJA`'I@R<$
M[[UF$6?UCV.)YPJ7AP``@[=GX8.V"0"(8UZ'%R8``!,&9N6)1>_@W[N!2@,W
MA/F#-PH`N8\!1V.2!S#Z8%ID%GOV:U9LMFRZ9!II]GE6>E:%MGH=88*`)H7O
MX)^NJH0A"^,)!?`UMX%$);<#-83IDP2$Z1G)RH7OX/_F`<6#1P4`E>.(9*$$
M??4U1>_@?XTJC*J*M4RU1)<K``"3BRO5$P<P!;F][^#?J:J+8=WOX%^*DQ05
M`(4$);V#*H3O[^!?B)L'!0#CD_KT@R<$[^KB$P<`')/W]Q]CB.<$%FT]MQ>'
M```#-R?4@[8)``AC%R8``!,&1M1>AXE%[^"?KC6W[_"?Q`,WA/F#-PH`N8\!
M1V.9!R):9/I@&FGV>59Z)H6Z9!UA;^#_H5J%[^"?@\J%JHH7)0``$P6%V>_@
MW]JJA6,-!1`#M0D`[_#OO*J,8P8%$&:%[^#O_QL,!0"-1V/8AP,3!<S_ER4`
M`).%Q=9FE>_@/Y()[9%'8P;\&)L'O/_FEP/'!P"3!_`"8PWW%LJ%%R4``!,%
MI;COX/_4<<&#1P4`W<\3!P`#8XSG"I<E``"3A67`%R4``!,%9;;OX#_V[^`_
MC"J(ER@``).(2."7)P``DX?'KEZ'ER8``).&IM):AHE%5H7OX-^A?5G%21<M
M```3#<W=ERP``).,3*P7+```$PQ,T26@[^"O]QQ!8Y<W`^_@'X>%)"J(:N"F
MB.:'7H?BAEJ&B456A>_@GYV3!0`<5H7OX/^.XP@E_5Z%[^!?C-:%%R4``!,%
MY:3OX#_M5H7O\'^O%FW1NX.\"0#5O8%%9H7OX/^@*HDIT>_PGYJJB>--!?*3
M!67_`49*A>_@7X83#`3V&4;BA4J%[^!_DIE'8Q_U"`,G!/:W1T%#DX<',.,5
M]_`#5TP`D6>3AX=4XQ[W[@%&DX7I_$J%[^!_@I,$A/83!H`"IH5*A>_@?XZ3
M!X`"8Q[U!)<H``"3B"C/)HB7)P``DX>'G5Z'ER8``).&9L!:AHE%5H4C"`3X
M[^!?D"V_@[F)`..#">A.A>_@3^2-1^/]I^9Q%9<E``"3A06\3I7OX._VXQ,%
MYLZ,A;47)0``$P4EN^_PWXCJXN_@7Y+6]MKRWN[BZN;FZN+OX%^177$F_)>$
M``"#M$2KHN!.]%+PAN1*^%;L@`BSAT0``[D'`!,*1/N7B0``@[FIIH-'"0O2
MA1<E```3!467`[<)`",\Y/H!1Z,(^0KOX+^T&<4#1P4`DP<0`V,!]Q3O\._#
MLX=$``.Y!P!*A8U&!4:7)0``DX6EMN_@K]\JB07%'&DSAT0`"&.,8Q<F```3
M!H:U[^`/WX,W"0&,8]Q%$Y>7`F-+!Q"SAT0`B&.-1@5&ER4``).%I;/OX*_;
M*HF7B@``DXK*J!7!TH47)0``$P6%B._@7ZPJAGG%@S<)`3.'1``(8XQC[^#/
MV;.'1``#N0<`!4:7)0``DX7EKTJ%[^!/S:J%%R8``!,&9K!*A>_@3]>2E)Q@
MTH47)0``$P6E@J.(!PKOX#^G([BJ`*J$*<F3!0`<)H7OX,_I&P<5`(5'8_#G
M`L5'8PWU`(.WB@"JAB:&C&,7)0``$P5EKN_@;^X#-X3[@[<)`+F/`4>A[Z9@
M!F3B=$)YHGD">N)J86&"@`.UB@#O\'^4([BJ`*J$3?$7)0``$P4EJ._@K^J#
M1Q4`XX4'[&V]`[>*`(,W"0$,8XAC[^"?WA6_LX=$`(AC[^!/Y=6U[^#O]#EQ
M(O@F]$KP@``&_)>$``"#M.2+*HF3!43\%Q4``!,%A7Z<8",T]/R!1^_@7YH)
MS8-'!0"1RQ,'``-CA^<`8P4)`(-'"0")[P,WA/R<8+F/`4>Y[^)P0G2B=`)Y
M(6&"@$J%3NSO\.^7DP7P`JJ)[^#/WAG!DPD5`$Z%[^`/VQ%&ER4``).%)8CO
MX"^W&<'B:66_`S>$_)Q@N8\!1YGK0G3B:>)PHG1*A0)Y(6%OX%^D3NSOX(_I
M$P$!TR,P@2PC/)$J@`TC-!$L(S@A*R,T,2LC,$$K(SQ1*9=T``"#M"1_DP:$
MTT%N_5Z<8",\]/J!1Y,(A0.3#X4'-HB3W@X"-P__`!,.#O`#M@@`00BA")-5
M!@(3%X8!DQ.&`)-7A@*34H8`$UF&`Q.3A0$S=]<!L_/C`;/WQP$S9W<`L_+"
M`;/G)P$S<],!H@4S9U<`&U:&`;/G9P"S]>4!48_-CR,XZ/XC//C^XY$?^_U5
M@S\$V@,_A-H#-P3;@SZ$U`,^!-4#,X35@S@$U@,XA-:#,P37$XD&((&1$:"R
M@[!BG&*Z@J$&L8^SQ_<!L\?7`1.7%P#]@UV/;8^X_OJ/\HX6CQJ.1H/"B!Z(
MXYDF_0,X!0"#/X33@S@%`0,^A0`#,X4!@SX%`C>&@EH3!I:9$U>X`9,76`#9
MC[*?$U\N`.V/]I\SQV@`DQ;N`;/FY@'^ES-WQP&#/P34,_^V`#-'9P"ZES/'
MZ`'MCS-W!P&RGY.35P`3V;<!FI\S1Q<!?I>S[R,!DUDH`),2Z`%^EX,_A-2S
MXC(!L\96`/V.LI]MC[/&Y@'&GY.3YP&)@[/C\P`3&5<`DUFW`;.']@&#/P35
MLV8Y`;:7L\9R`+*?L_*R`/F.[8]^G[/&5@`3F5<`D]FW`9,?YP'ZE@F#`S^$
MU;/O[P`S9SD!NI8SQ_,![8ZS\[,`?8\RGQ:?$YE6`)/9M@$S1W<`DY+G`8F#
ML^+R`'J7LV<Y`3Z7,W^W``,W!-:SQU\`]8^S_[\`,I<>EQ,97P"36;\!L\?W
M`;J7,V<Y`;J7DY/F`8F"L^/3`+/VMP"#-X36,\=R`#-WYP&S\K(`LI?^EQ.9
M5@"3V;8!,T=7`#Z7LV<Y`3Z7DQ_O`1-?+P"S[^\!,W^W``,W!->SQ_,!]8^S
M\[,`,I<6EQ,97P"36;\!L\=W`+J7,V<Y`;J7DY+F`8F"L^+2`+/VMP"#-X37
M,\=?`#-WYP&S_[\`LI>>EQ.95@"3V;8!,T?W`3Z7LV<Y`3Z7DQ/O`1-?+P"S
MX^,!,W^W``,W!-BSQW(`]8^S\K(`,I=^EQ,97P"36;\!L\=7`+J7,V<Y`;J7
MDY_F`8F"L^_?`+/VMP"#-X38,\?S`3-WYP&S\[,`LI>6EQ.95@"3V;8!,T=W
M`#Z7LV<Y`3Z7DQ+O`1-?+P"SXN(!,W^W``,W!-FSQU\`]8^S_[\`,I<>EQ,9
M7P"36;\!L\?W`;J7,V<Y`;J7DY/F`8F"L^/3`+/VMP"#-X39,\=R`#-WYP&S
M\K(`LI?^EQ.95@"3V;8!,T=7`#Z7LV<Y`3Z7DQ_O`1-?+P"S[^\!,W^W``,W
M!-JSQ_,!]8^S\[,`,I<6EQ,97P"36;\!L\=W`+J7,V<Y`;J7DY+F`8F"L^+2
M`+/VMP"#-X3:,\=?`#-WYP&S_[\`LI>>EQ.95@"3V;8!,T?W`3Z7LV<Y`3Z7
MDQ/O`1-?+P"SX^,!,W^W``,W!-NSQW(`]8^S\K(`,I=^EQ,97P"36;\!L\=7
M`+J7,V<Y`;J7DY_F`8F"L^_?`+/VMP"#-X3;,\?S`3-WYP&RE[/SLP"6EY,2
M[P$37R\`L^+B`1.95@"3V;8!`S\$W#-'=P`^E[-G.0$^E[/'7P!MC[/_OP#U
MCS*?'I\36;<!L\?W`9,35P"SXR,!^I<#.83<$Y_F`8F",V_?`)Z7[8^SQN(!
M,IFS\K(`D]FW`?F.DY-7`,J?L\96`+/C,P&S\[,`_I:>EI,?YP&#,P3="8.S
M[^\`,_FV`#-'_P&RDS-_OP"36;D!?8\3%ED`GI(S1^<!,V8V`1:7;8ZS`\<`
MDY+G`0,VA-V)@[/B\@`W]]EN$P<7NK/YLP"SQU\`$]JY`;6/.I:3EED`>I;M
MC[/F1@'MCK*7,X;7`!,?Z0&#-P3>$UDI`#-O+P&SQN(!,WFV`#/ZOP"ZE[//
M=@"34[D!DQ99`+/_OP#2E[/F=@#^E^V.OI:3G^D!@S>$WI/9*0"S[S\!L_.V
M`+-)_P$S^K(`NI>SPLD`D]FS`1.64P"S\K(`TI<S9C8!EI=MCCZ6DQ+I`8,W
M!-\362D`L^(B`;/)7P`S>;8`,WJ_`+J7,\_9`)-9N0&3%ED`,W^_`-*7L^8V
M`?J7[8Z^EA.?XP&#-X3?D],C`#-O?P"SR>(!L_.V`#/ZOP"ZE[//R0"3V;,!
M$Y93`+/_OP#2ES-F-@'^EVV./I:3'^D!@S<$X!-9*0"S[R\!LTG_`3-YM@`S
M^K(`NI>SPMD`DUFY`9,660"S\K(`TI>SYC8!EI?MCKZ6DY+C`8,WA."3TR,`
ML^)R`+/)7P"S\[8`,WJ_`+J7,\_)`)/9LP$3EE,`,W^_`-*7,V8V`?J7;8X^
MEA,?Z0&#-P3A$UDI`#-O+P&SR>(!,WFV`#/ZOP"ZE[//V0"36;D!DQ99`+/_
MOP#2E[/F-@'^E^V.OI:3G^,!@S>$X9/3(P"S[W\`LTG_`;/SM@`S^K(`NI>S
MPLD`D]FS`1.64P"S\K(`TI<S9C8!EI=MCCZ6DQ+I`8,W!.(362D`L^(B`;/)
M7P`S>;8`,WJ_`+J7,\_9`)-9N0&3%ED`,W^_`-*7L^8V`?J7[8Z^EA.?XP&#
M-X3BD],C`#-O?P"SR>(!L_.V`#/ZOP"ZE[//R0"3V;,!$Y93`+/_OP#2ES-F
M-@'^EVV./I:3'^D!@S<$XQ-9*0"S[R\!LTG_`3-YM@`S^K(`NI>SPMD`DUFY
M`9,660"S\K(`TI>SYC8!EI?MCKZ6DY+C`8,WA..3TR,`L^)R`+/)7P"S\[8`
M,WJ_`+J7,\_)`)/9LP$3EE,`,W^_`-*7,V8V`?J7;8X^EA,?Z0&#-P3D$UDI
M`#-O+P&SR>(!,WFV`#/ZOP"ZE[//V0"36;D!DQ99`+/_OP#2E[/F-@'^E^V.
MOI:3G^,!@S>$Y)/3(P"S[W\`LTG_`;/SM@`S^K(`NI>SPLD`D]FS`1.64P"S
M\K(`TI<S9C8!EI=MCCZ6DQ+I`8,W!.4362D`L^(B`;/)7P`S>;8`,WJ_`+J7
M,\_9`)-9N0&3%ED`,W^_`-*7L^8V`?J7[8Z^EA.?XP&#-X3ED],C`#-O?P"S
MR>(!L_.V`#/ZOP"ZE[//R0"3V;,!$Y93`+/_OP#2ES-F-@'^EVV./I:3'^D!
M@S<$YA-9*0"S[R\!LWFV`#-)_P&S\K(`$]JY`;J7,TG9`).660`S>;D`EI>S
MXD8!$YKC`9/6(P"S8]H`RI>S]K(`OI:#-X3FL\)_`#/YM@`S?[\`,\;"`+J7
MDQ)9`!-:N0'ZES-_M@#ZES/O0@'ZEQ.6Z0$#/P3GD]DI`#-F-@&SR<,`L_*W
M`+/_OP"SQ]D`.I\3VK(!?I^3F5(`L_^W`+/I20%^GTZ?DQ;I`1-9*0"SYB8!
M-_?&(S-YM@#]5[-UOP`#/X3G@9,*!Q,'Q\VS__8`58ZS>?D!.I\S=E8`L_/S
M`/J3$]JU`3-F-@$3G^(!DYE5`)/2(@`S;U\`'I:SXDD!%I:#,@3HLW/_`+/F
MY@%]CK/Y?P#MCKJ2RI*SYC8!$QE6`)-9M@$S:3D!EI83FN4!RI:)@0,YA.BS
M9;H`L_+U`#-OOP#]CK/Y4P`S?\\`.IDS;S\!?IF3F58`$]JV`9,?Y@$)@K/O
MSP`S!B\!,^])`7J6`S\$Z3/Y_P"SY?4!?8ZS^2(!.I_UC;/E-0'ZDY,95@`3
M6K8!$Y_F`8F",V_?`+.&=0"SY4D!KI:#-83ILW/_`+/O[P']CK-Y>0"ZE;/_
MSP"S[S\!KI*3F58`$]JV`9,5Y@$)@M&-,X9?`+/O20%^EH,_!.JS\O4`,V^_
M`'V.L_E3`+J?,W_?`#-O/P%^F9,95@`36K8!DY_F`8F"L^_?`+,&+P$S[TD!
M^I8#/X3J,_G_`+/E]0']CK/Y(@$ZG_&-L^4U`?J3DYE6`!/:M@$3'^8!"8(S
M;\\`,X9U`+/E20$NEH,U!.NS<_\`L^_O`7V.LWEY`+J5L__?`+/O/P&NDI,9
M5@`36K8!DY7F`8F"U8VSAE\`L^])`?Z6@S^$Z[/R]0`S;[\`_8ZS^5,`NI\S
M?\\`,V\_`7Z9DYE6`!/:M@&3'^8!"8*S[\\`,P8O`3/O20%ZE@,_!.PS^?\`
ML^7U`7V.L_DB`3J?]8VSY34!^I.3&58`$UJV`1.?Y@&)@C-OWP"SAG4`L^5)
M`:Z6@S6$[+-S_P"S[^\!_8ZS>7D`NI6S_\\`L^\_`:Z2DYE6`!/:M@&3%>8!
M"8+1C3.&7P"S[TD!?I:#/P3ML_+U`#-OOP!]CK/Y4P"ZGS-_WP`S;S\!?IF3
M&58`$UJV`9.?Y@&)@K/OWP"S!B\!,^])`?J6`S^$[3/Y_P"SY?4!_8ZS^2(!
M.I_QC;/E-0'ZDY.95@`3VK8!$Q_F`0F",V_/`#.&=0"SY4D!+I:#-03NLW/_
M`+/O[P%]CK-Y>0"ZE;/_WP"S[S\!KI*3&58`$UJV`9.5Y@&)@M6-LX9?`+/O
M20'^EH,_A.ZS\O4`,V^_`/V.L_E3`#-_SP"ZG\J?,V\_`1.95@"3V;8!,VDY
M`7Z?2I\S>?\`$QKF`0,_!.\)@C-FR@"S?_8`T8VS^?(!]8TZGQZ?L^4U`9,3
M60"36;D!$YKF`?J5B8(S[S,!@SF$[[-FV@"S\_8`^I55CC/_]0`S=B8!L_5_
M`+J9EID3&E\`DUJ_`4V.DU(I`),5Z0%.EC-I6@%*E@,Y!/"SY54`L_+U`,V.
M?8ZS^5,`.IFS]N8!RI^SYC8!$QE6`)-9M@'^EK-O.0'^EI,9[P&#/X3P$U\O
M`+/IZ0$S^?D`L^4U`3/_]@"S^B(!\8VZGY,67P`36K\!GI^SY54!L^-&`?Z5
MDQ;F`9-?)@"SYO8!L_/S`#/FV0"#.03QGI6S\_4`L__V`+-Z^0$3VK,!,W;F
M`;J9$Y=3`):9,V96`;-B1P%.EK/R\@"RDI,9[P$#-H3Q$U\O`#>WF#(S[^D!
M"@<3!V<=L\;F`:V..I9*EOV.L_GR`+*6$YGC`1/6(P"S8\D`$]JY`9.560`S
M1G\`L^5%`?V-,T96`(,R!/*VE3/Y]0"ZDA-:N0&3%ED`EI]]CK/F1@']CGZ6
M-I:3DND!@S:$\I/9*0"SXC(!L\]3`+-Y]@`S>O\`NI8SS[\`D]^Y`9.560`S
M?_\`TI:SY?4!^I;]C;:5$Q_I`8,V!/,362D`,V\O`;//X@$S^?4`L_/S`!-:
MN0&ZEK//SP`3%ED`L___`)Z6,V9&`?Z6?8XVEI.?Z0&#-H3SD]DI`+/O/P&S
M<_8`LTG_`3/Z\@"ZEK/"N0"3V;,!DY53`+/R\@#2EK/E-0&6EOV-MI63$ND!
M@S8$]!-9*0"SXB(!L\E?`#/Y]0`S>O\`NI8SS\D`DUFY`1,660`S?_\`TI8S
M9C8!^I9]CC:6$Y_C`8,VA/23TR,`,V]_`+/)X@&S<_8`,_K_`+J6L\^Y`)/9
MLP&3E5,`L___`-*6L^4U`?Z6_8VVE9,?Z0&#-@3U$UDI`+/O+P&S2?\!,_GU
M`#/Z\@"ZEK/"R0"36;D!$Q99`+/R\@#2EC-F-@&6EGV.-I:3DN,!@S:$]9/3
M(P"SXG(`L\E?`+-S]@`S>O\`NI8SS[D`D]FS`9.54P`S?_\`TI:SY34!^I;]
MC;:5$Q_I`8,V!/8362D`,V\O`;/)X@$S^?4`,_K_`+J6L\_)`)-9N0$3%ED`
ML___`-*6,V8V`?Z6?8XVEI.?XP&#-H3VD],C`+/O?P"S2?\!LW/V`#/Z\@"Z
MEK/"N0"3V;,!DY53`+/R\@#2EK/E-0&6EOV-MI63$ND!@S8$]Q-9*0"SXB(!
ML\E?`#/Y]0`S>O\`NI8SS\D`DUFY`1,660`S?_\`TI8S9C8!^I9]CC:6$Y_C
M`8,VA/>3TR,`,V]_`+/)X@&S<_8`,_K_`+J6L\^Y`)/9LP&3E5,`L___`-*6
ML^4U`?Z6_8VVE9,?Z0&#-@3X$UDI`+/O+P&S2?\!,_GU`#/Z\@"ZEK/"R0"3
M6;D!$Q99`+/R\@#2EC-F-@&6EGV.-I:3DN,!@S:$^)/3(P"SXG(`L\E?`+-S
M]@`S>O\`NI8SS[D`D]FS`9.54P`S?_\`TI:SY34!^I;]C;:5$Q_I`8,V!/D3
M62D`,V\O`;/)X@$S^?4`,_K_`+J6L\_)`)-9N0$3%ED`L___`-*6,V8V`?Z6
M?8XVEI.?XP&#-H3YD],C`+/O?P"S2?\!LW/V`#/Z\@"ZEK/"N0"3V;,!DY53
M`+/R\@#2EK/E-0&6EOV-MI63$ND!@S8$^A-9*0"SXB(!L_GU`#/)7P`S?_\`
M$]JY`;J6,TG)`!.660`S>?D`^I8S9D8!RI9]CA.?XP&3TR,`,V]_`+.#Q@`#
M-H3ZL\;B`3/Y\P"S__\`.I:MCOV.DQ59`'Z6$UJY`3:6L^9%`3:6@S8$^Y.?
MZ0&3V2D`L^\_`3:7LT;_`;-U]@!"E[/R\@"SQG8`_8X3EE4`$]BU`1:7-I>S
M9@8!$Q;I`1-9*0`VES-F)@%]CT:6\I6:G[,&WP$8X?V-,W?V`#/V_P#UCQCI
M'/$,Y1#M`S>$^YQ@N8\!1Y7C@S"!+`,T`2R#-($K`SD!*X,Y@2H#.@$J@SJ!
M*1,!`2V"@._03[9!$2+@!N0`"!,%``COT$^%MW9=3#=WZ6&W)45GDX45,(8&
M-U8R$`8'#.&3AN;/ET4``(.UI443!F9'$P<''PSE%.D0[1CQ(S0%`B,X!0(C
M+`4&HF`"9$$!@H`Y<2+X)O1*\$[L5N0&_%+H6N"``!AUDQ<V`!1YNI>"%X&3
M,[?G`"J)NI8H71-7U@$VER,T^0(C..D"LHFNA),*B0,Y[9,'\`-CWS<)FXD)
M_!O;:0`;"AL`&@HFFJ:%$P8`!%:%[]`OBY.$!`1*A>_@7\#CE43_&QMK`+N)
M:4%.AM*%5H7OT"^)(RPY!^)P0G2B=`)YXFE":J)J`FLA88*`$PH`!+L'JD`^
MBF-,]@(;"PH`DPJ)`UJ&IH56E>_0KX6#)XD'$P<`!+L&^@`C+-D&XY[F^DJ%
MNXE)0=J4[^!_N96W,HKIMR:*6;\Y<2+X)O1*\%;D!OQ.[%+H@``#NH4"DXJ%
M`Y,&`/@35CH`$W;V`S.'R@"#N04#DP<6`",`UP`3!X`#KH0JB04F8UCW$A,'
M``01GY%&,X7Z`&-VUQ2)1V-Z]Q)C%0<2)H7OX)^R$P:``X%%5H7OT`^1D]8)
M`1/7B0"3]O8/H@:;UXD!$W?W#T('U8^3^?D/X@G9CQM6B@&35@H!`A:SYS<!
M$U>*`)/V]@^B%M&/$W?W#T(7U8]B&MF/L^='`;SX)H7OX)^LG&`FA>&#(P#Y
M`)Q@P8.C`/D`G&"A@R,!^0"<8*,!^0"<9.&#(P+Y`)QDP8.C`OD`G&2A@R,#
M^0"<9*,#^0"<:.&#(P3Y`)QHP8.C!/D`G&BA@R,%^0"<:*,%^0"<;.&#(P;Y
M`)QLP8.C!OD`G&RA@R,'^0"<;*,'^0"<<.&#(PCY`)QPP8.C"/D`G'"A@R,)
M^0"<<*,)^0!"=.)PHG0">>)I0FJB:B%A;\`?]1,'@`,[!L=`@44SA?H`[\#_
M__VU(P`%`-F](P`%`*,`!0!Y%PD%XP0'[.VW(P`%`*,`!0`C`04`HP$%`'$7
MB4<1!>-D]^K1OT$1(N0`"")DEV8``(.VQB-!`6_`/^`````````!``(`````
M`"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````97AE```````O
M<')O8R\E:2\E<P``````+@````````!005)?5$5-4```````````4$%27U!2
M3T=.04U%`````#H`````````+P`````````E<R5S)7,``%!%4DPU3$E"````
M``````!015),3$E"`%!%4DPU3U!4``````````!015),24\``%!!4E])3DE4
M24%,25I%1`!005)?4U!!5TY%1```````4$%27T-,14%.`````````%!!4E]$
M14)51P````````!005)?0T%#2$4`````````4$%27T=,3T)!3%]$14)51P``
M````````4$%27T=,3T)!3%]435!$25(`````````4$%27U1-4$1)4@``````
M`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.```````````Q````
M`````&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9```````3$1?3$E"4D%2
M65]0051(`%-94U1%30``+W1M<`````!54T52`````%5315).04U%````````
M```E,#)X`````'!A<BT`````)7,E<R5S)7,``````````"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M````````4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```````
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M
M)74E<P``````````&`````````!P97)L`````#``````````4$%2.CI086-K
M97(Z.E9%4E-)3TX`````,2XP-C,```!5;F%B;&4@=&\@8W)E871E(&-A8VAE
M(&1I<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C
M:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````
M+64````````M+0```````%1-4$1)4@``5$5-4$1)4@!414U0`````%1-4```
M````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG
M"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E
M(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L
M("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y0
M05(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB
M*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP
M,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?
M.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I
M>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@
M)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L
M92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H
M+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!
M4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]
M("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D
M<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M
M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q
M,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q
M8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P
M-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU
M;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C
M:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE
M72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y
M<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z
M("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\
M8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@
M/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA
M;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E
M=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6
M>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%
M7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2![
M"F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@
M(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*
M;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H
M*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I
M;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA
M;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T
M('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR
M96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE
M(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C
M86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A
M8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P
M;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&
M24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U
M9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S
M970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ
M92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL
M(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@
M("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,
M12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T
M.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL
M;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M
M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=
M>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@
M/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII
M9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA
M;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN
M86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F
M=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E
M='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92([
M"FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN
M97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@
M(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D[
M"B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE
M?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U
M<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I
M;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@
M>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@
M9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@
M>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II
M9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS
M)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O
M7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I
M9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;
M,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?
M4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%2
M1U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*
M:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q
M("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q
M("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N
M9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]
M("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE
M;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D
M:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@
M*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6
M*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6
M>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*
M)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ
M1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T
M($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L
M("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D
M(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B
M(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'
M24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@
M24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/
M.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L
M"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD
M9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF
M("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L
M("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO
M8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I
M('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R
M.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B
M)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D[
M"G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.
M+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N
M9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O
M;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F
M;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN
M84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D
M;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C
M(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE
M*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE
M;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\
M7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ
M*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I
M;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER
M+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S
M=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF
M("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D
M9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M0
M86-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M
M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*
M)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@
M=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;
M0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L
M;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E
M;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII
M<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@
M=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q
M6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^
M=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET[
M"GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!
M3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@
M)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M
M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D
M8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@
M+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM
M>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^
M8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U
M="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL
M97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U
M:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E
M<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*
M)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E
M;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M
M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R
M8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ
M92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2
M.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN
M9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S
M:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E
M<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E
M8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN
M97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@
M)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF
M("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S
M<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@
M<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@
M96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B
M)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE
M9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I
M92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA
M;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X
M(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI
M('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*
M+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T
M*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*
M<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L
M("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<
M+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T
M:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H
M(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR
M97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S
M=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER
M92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q
M=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z
M.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U
M:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M
M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I
M9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER
M92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E
M<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T[
M"F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@
M<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A
M;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@
M;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$
M25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I
M"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A
M;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@
M9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97
M:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD
M=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[
M55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T
M;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@
M)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D
M:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP
M+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H
M*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2![
M"G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L
M96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L
M(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D
M9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*
M)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II
M9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.
M5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M)&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F
M("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,
M3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P97)L>'-I+F,``````````$-!
M0TA%``")J\WO``````$;`SOL````'````/".__\X!P``G)#__P0!``!4D?__
M&`$```J2__^0`0``=I+__\@!``",D___+`(``%B5__^@`@``+);__^0"``",
MEO__$`,``+Z6__\T`P``>)?__W@#``"$E___G`,``$"9___X`P``:)G__R0$
M``!:FO__<`0``-B=__^P!```,I[__^`$``""GO__``4``)B?__]4!0``MI__
M_WP%``"(H/__Y`4``,"E__^8!@``AJ?__]P&```\J/__>`<``'"[__^\!P``
MRKO__^0'``"TO/__*`@``&R^__]H"````````!```````````WI2``%\`0$;
M#0(`$````!@```"0C___(@`````'`0!T````+````#20__^V`````$(.4$:(
M!($"B09"#`@`3)<24I,*E`R5#F:2")80:-)"TT+40M5"UD+70L%"R`P"4$3)
M0@X`0@T(@0*(!(D&D@B3"I0,E0Z6$)<24M+3U-76UT27$D+71),*E`R5#I<2
M1M-"U$+50M<T````I````'*0__]L`````$(.L`%&B`2)!I((0@P(`$*!`@)2
M"L%"R`P"L`%"R4+20@X`0@L``&````#<````II#__Q8!````0@[0`4:(!)0,
M@0)"#`@`6HD&1LE2P4+(#`+0`4+40@X`0@T(@0*(!(D&E`Q$D@B3"G*5#@)<
MU50*R4+20M-""U*5#DC)TM/52(D&D@B3"I4.``!P````0`$``%B1___,`0``
M`$(.<%*(!(D&D@B3"I4.@0*4#)<2F!1"#`@``MX*P4+(#`)P0LE"TD+30M1"
MU4+70MA"#@!""W"6$)D6FA@"6`K60ME"VD8+5M;9VD26$)D6FAA&UMG:1I80
MF1::&$;60ME"VD````"T`0``L)+__]0`````0@Y03(@$B0:2"),*E`R5#D(,
M"`!6@0("9@H,`E!"P4+(0LE"TD+30M1"U4(.`$(+````*````/@!``!`D___
M8`````!"#B!"B09,B`2!`D(,"`!FR`P"($3!0LE>#@`@````)`(``'23__\R
M`````$(.$$J(`D(,"`!"R`P"$%X.``!`````2`(``(*3__^Z`````$(.8$:!
M`H@$B09"#`@`2I((DPJ4#)4.`HX*#`)@0L%$R$+)0M)"TT+40M5"#@!""P``
M`"````",`@``^)/__PP`````0@X00H@"0@P(`$+(#`(00@X``%@```"P`@``
MX)/__[P!````0@Z``DJ(!(D&D@B3"I@40@P(`&*!`I0,E0Z6$)<2F1::&)L:
M`E`*#`*``D+!0LA"R4+20M-"U$+50M9"UT+80ME"VD+;0@X`0@L`*`````P#
M``!`E?__*`````!"#B!&B`2)!H$"0@P(`%+(#`(@0L%$R4(.``!(````.`,`
M`#R5___R`````$(.0$J(!),*@0*)!I((0@P(``*>"@P"0$+!0LA"R4+20M-"
M#@!""U(*#`)`0L%"R$+)0M)"TTH.`$0+/````(0#``#BE?__?@,```!"#D!*
MB`2)!I((DPJ4#$(,"`!"@0(#*@,*R`P"0$+!0LE"TD+30M12#@!$"P```"P`
M``#$`P``()G__UH`````0@XP1(@$B09"#`@`0H$"`D`*P4+(#`(P0LE"#@!"
M"QP```#T`P``2IG__U``````0@Y@1(@4@1)"#`A`````4````!0$``!ZF?__
M%@$```!"#G!8B`24#)4.FAB!`HD&D@B3"I80EQ*8%)D60@P(``*X"@P"<$+!
M0LA"R4+20M-"U$+50M9"UT+80ME"VD(.`$(+)````&@$```\FO__'@````!"
M#A!$B`2!`D(,"`!0P4+(#`(00@X``&0```"0!```,IK__](`````0@Y`1H@$
MD@B3"D(,"`!B@0),B09&R5K(#`)`0L%"TD+30@X`1`T(@0*(!(D&D@B3"D24
M#`)$R`P"0$+40L%"TD+31,E*#@!$#0B!`H@$D@B3"D2)!I0,L````/@$``"<
MFO__.`4```!"#J`#1(@$D@A"#`@`8),*E`R!`HD&`HR5#I80EQ*8%)D6`W`!
M"L%"R`P"H`-"UD+70MA"V4+)0M)"TT+41-5"#@!""P*`FAA&VF+5UM?8V5;(
M#`*@`T+!0M)"TT+41,E"#@!$#0B!`H@$B0:2"),*E`R5#I80EQ*8%)D6FA@#
M,`$*VD(+`^(`VD*:&$35UM?8V=I,E0Z6$)<2F!29%IH8````0````*P%```@
MG___Q@$```!"#E!"B094B`23"I0,@0*2")4.0@P(``-4`0K!0L@,`E!"R4+2
M0M-"U$+50@X`0@L```!8````\`4``**@__^V`````$(.0$:(!(D&D@A"#`@`
M8($";`K!0L@,`D!"R4+20@X`0@M$DPIL"M-""T[(#`)`0M-"P4+)1-)"#@!$
M#0B!`H@$B0:2"$*3"@```#P```!,!@``L(?__ZP!````0@Y@1H$"B`22"$(,
M"`!&B0:3"I0,`RP!"L%"R`P"8$+)0M)"U$330@X`0@L```!`````C`8``+R@
M__\T$P```$0.T`5(B`2)!D(,"`!4@0*2"),*E`R5#@/P$@K!1,@,`M`%1,E$
MTD331-1$U40.`$(+`"0```#0!@``K+/__UH`````0@X01(@$@0)"#`@``DS!
M0L@,`A!"#@!`````^`8``-ZS___J`````$(.0%"(!(D&D@B3"I4.@0*4#)80
M0@P(``)Z"L%"R`P"0$+)0M)"TT+40M5"UD(.`$(+`#P````\!P``A+3__[@!
M````0@Y`3H@$B0:2")4.@0*3"I0,0@P(``-,`0K(#`)`0L%"R4+20M-"U$+5
M0@X`1`L@````?`<``/RU__\6`````$(.$$*(`D(,"`!"R`P"$$H.````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````$`````````^0(`````
M```!``````````D#`````````0`````````3`P```````"``````````F*L`
M```````A``````````@`````````&0````````"@JP```````!L`````````
M"``````````:`````````*BK````````'``````````(`````````/7^_V\`
M````V`(````````%`````````$`-````````!@````````#(`P````````H`
M````````O00````````+`````````!@`````````%0``````````````````
M``,`````````P*T````````"`````````%@%````````%``````````'````
M`````!<`````````.!4````````'`````````"@3````````"`````````!H
M!P````````D`````````&``````````>``````````@`````````^___;P``
M```!```(`````/[__V\`````R!(```````#___]O``````(`````````\/__
M;P````#^$0```````/G__V\`````"P``````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````/__________``````````"0&@```````)`:
M````````D!H```````"0&@```````)`:````````D!H```````"0&@``````
M`)`:````````D!H```````"0&@```````)`:````````D!H```````"0&@``
M`````)`:````````D!H```````"0&@```````)`:````````D!H```````"0
M&@```````)`:````````D!H```````"0&@```````)`:````````D!H`````
M``"0&@```````)`:````````D!H```````"0&@```````)`:````````D!H`
M``````"0&@```````)`:````````D!H```````"0&@```````)`:````````
MD!H```````"0&@```````)`:````````D!H```````"0&@```````)`:````
M````D!H```````"0&@```````)`:````````D!H```````"0&@```````)`:
M````````D!H```````"0&@```````)`:````````D!H```````"0&@``````
M`)`:````````D!H```````"0&@```````)`:````````D!H```````"PJP``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M1T-#.B`H56)U;G1U(#$S+C(N,"TR-'5B=6YT=3$I(#$S+C(N,`!!4@```')I
M<V-V``%(````!!`%<G8V-&DR<#%?;3)P,%]A,G`Q7V8R<#)?9#)P,E]C,G`P
M7WII8W-R,G`P7WII9F5N8V5I,G`P7WIM;75L,7`P```N<VAS=')T86(`+FEN
M=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA
M<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?
M<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+G!R96EN:71?87)R87D`+FEN:71?87)R87D`+F9I
M;FE?87)R87D`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"YR
M:7-C=BYA='1R:6)U=&5S````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M````````<`(```````!P`@```````"$````````````````````!````````
M````````````$P````<````"`````````)0"````````E`(````````D````
M````````````````!````````````````````"8````'`````@````````"X
M`@```````+@"````````(`````````````````````0`````````````````
M```T````]O__;P(`````````V`(```````#8`@```````.P`````````!0``
M```````(````````````````````/@````L````"`````````,@#````````
MR`,```````!X"0````````8````"````"``````````8`````````$8````#
M`````@````````!`#0```````$`-````````O00```````````````````$`
M``````````````````!.````____;P(`````````_A$```````#^$0``````
M`,H`````````!0`````````"``````````(`````````6P```/[__V\"````
M`````,@2````````R!(```````!@``````````8````"````"```````````
M`````````&H````$`````@`````````H$P```````"@3````````$`(`````
M```%``````````@`````````&`````````!T````!````$(`````````.!4`
M```````X%0```````%@%````````!0```!0````(`````````!@`````````
M>0````$````&`````````)`:````````D!H```````"P`P``````````````
M````$``````````0`````````'X````!````!@````````!`'@```````$`>
M````````DB\```````````````````0```````````````````"$`````0``
M``(`````````V$T```````#830```````'A!```````````````````(````
M````````````````C`````$````"`````````%"/````````4(\```````#L
M````````````````````!````````````````````)H````!`````@``````
M``!`D````````$"0````````H`<```````````````````@`````````````
M``````"D````$`````,`````````F*L```````"8FP````````@`````````
M```````````!``````````@`````````LP````X````#`````````*"K````
M````H)L````````(````````````````````"``````````(`````````+\`
M```/`````P````````"HJP```````*B;````````"```````````````````
M``@`````````"`````````#+````!@````,`````````L*L```````"PFP``
M`````!`"````````!@`````````(`````````!``````````U`````$````#
M`````````,"M````````P)T```````!``@``````````````````"```````
M```(`````````-D````!`````P``````````L`````````"@````````4```
M``````````````````@```````````````````#?````"`````,`````````
M4+````````!0H````````"@````````````````````(````````````````
M````Y`````$````P````````````````````4*`````````F````````````
M`````````0`````````!`````````.T````#``!P````````````````````
M`':@````````4P````````````````````$````````````````````!````
M`P````````````````````````#)H````````/\````````````````````!
/````````````````````
